@@ -11,6 +11,7 @@ from bokeh.io import show
 from .compute import compute_missing
 from .render import render_missing
 from ..report import Report
+from ..dtypes import DTypeDef
 
 __all__ = ["render_missing", "compute_missing", "plot_missing"]
 
@@ -23,6 +24,7 @@ def plot_missing(
     bins: int = 30,
     ncols: int = 30,
     ndist_sample: int = 100,
+    dtype: Optional[DTypeDef] = None,
 ) -> Report:
     """
     This function is designed to deal with missing values
@@ -43,6 +45,11 @@ def plot_missing(
         The number of rows in the figure
     ndist_sample
         The number of sample points
+    wdtype: str or DType or dict of str or dict of DType, default None
+        Specify Data Types for designated column or all columns.
+        E.g.  dtype = {"a": Continuous, "b": "Nominal"} or
+        dtype = {"a": Continuous(), "b": "nominal"}
+        or dtype = Continuous() or dtype = "Continuous" or dtype = Continuous()
 
     Examples
     ----------
@@ -52,6 +59,8 @@ def plot_missing(
     >>> plot_missing(df, "HDI_for_year")
     >>> plot_missing(df, "HDI_for_year", "population")
     """
-    itmdt = compute_missing(df, x, y, bins=bins, ncols=ncols, ndist_sample=ndist_sample)
+    itmdt = compute_missing(
+        df, x, y, dtype=dtype, bins=bins, ncols=ncols, ndist_sample=ndist_sample
+    )
     fig = render_missing(itmdt)
     return Report(fig)
